@@ -1,14 +1,14 @@
-package LCFG::Build::Tool;    # -*-cperl-*-
+package LCFG::Build::Tool;    # -*-perl-*-
 use strict;
 use warnings;
 
-# $Id: Tool.pm.in 23959 2013-10-11 12:53:58Z squinney@INF.ED.AC.UK $
+# $Id: Tool.pm.in 29224 2015-11-12 10:11:34Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Tool.pm.in,v $
-# $Revision: 23959 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_1/lib/LCFG/Build/Tool.pm.in $
-# $Date: 2013-10-11 13:53:58 +0100 (Fri, 11 Oct 2013) $
+# $Revision: 29224 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_2/lib/LCFG/Build/Tool.pm.in $
+# $Date: 2015-11-12 10:11:34 +0000 (Thu, 12 Nov 2015) $
 
-our $VERSION = '0.6.1';
+our $VERSION = '0.6.2';
 
 use File::HomeDir;
 use File::Spec;
@@ -166,7 +166,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::Tool version 0.6.1
+    This documentation refers to LCFG::Build::Tool version 0.6.2
 
 =head1 SYNOPSIS
 
