@@ -1,14 +1,14 @@
-package LCFG::Build::Tool::CheckMacros;    # -*-cperl-*-
+package LCFG::Build::Tool::CheckMacros;    # -*-perl-*-
 use strict;
 use warnings;
 
-# $Id: CheckMacros.pm.in 23323 2013-05-14 08:12:39Z squinney@INF.ED.AC.UK $
+# $Id: CheckMacros.pm.in 29224 2015-11-12 10:11:34Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Tool/CheckMacros.pm.in,v $
-# $Revision: 23323 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_1/lib/LCFG/Build/Tool/CheckMacros.pm.in $
-# $Date: 2013-05-14 09:12:39 +0100 (Tue, 14 May 2013) $
+# $Revision: 29224 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_2/lib/LCFG/Build/Tool/CheckMacros.pm.in $
+# $Date: 2015-11-12 10:11:34 +0000 (Thu, 12 Nov 2015) $
 
-our $VERSION = '0.6.1';
+our $VERSION = '0.6.2';
 
 use File::Spec ();
 use File::Temp ();
@@ -303,7 +303,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::Tool::CheckMacros version 0.6.1
+    This documentation refers to LCFG::Build::Tool::CheckMacros version 0.6.2
 
 =head1 SYNOPSIS
 
