@@ -1,14 +1,14 @@
-package LCFG::Build::Tool::DevOSXPkg;    # -*-cperl-*-
+package LCFG::Build::Tool::DevOSXPkg;    # -*-perl-*-
 use strict;
 use warnings;
 
-# $Id: DevOSXPkg.pm.in 20973 2012-05-18 16:54:45Z squinney@INF.ED.AC.UK $
+# $Id: DevOSXPkg.pm.in 29224 2015-11-12 10:11:34Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Tool/DevOSXPkg.pm.in,v $
-# $Revision: 20973 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_1/lib/LCFG/Build/Tool/DevOSXPkg.pm.in $
-# $Date: 2012-05-18 17:54:45 +0100 (Fri, 18 May 2012) $
+# $Revision: 29224 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_2/lib/LCFG/Build/Tool/DevOSXPkg.pm.in $
+# $Date: 2015-11-12 10:11:34 +0000 (Thu, 12 Nov 2015) $
 
-our $VERSION = '0.6.1';
+our $VERSION = '0.6.2';
 
 use LCFG::Build::Utils::OSXPkg;
 
@@ -77,7 +77,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::Tool::DevOSXPkg version 0.6.1
+    This documentation refers to LCFG::Build::Tool::DevOSXPkg version 0.6.2
 
 =head1 SYNOPSIS
 
