@@ -1,14 +1,14 @@
-package LCFG::Build::Tool::DevPack;    # -*-cperl-*-
+package LCFG::Build::Tool::DevPack;    # -*-perl-*-
 use strict;
 use warnings;
 
-# $Id: DevPack.pm.in 12955 2010-07-20 13:13:37Z squinney@INF.ED.AC.UK $
+# $Id: DevPack.pm.in 29224 2015-11-12 10:11:34Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Tool/DevPack.pm.in,v $
-# $Revision: 12955 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_1/lib/LCFG/Build/Tool/DevPack.pm.in $
-# $Date: 2010-07-20 14:13:37 +0100 (Tue, 20 Jul 2010) $
+# $Revision: 29224 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_2/lib/LCFG/Build/Tool/DevPack.pm.in $
+# $Date: 2015-11-12 10:11:34 +0000 (Thu, 12 Nov 2015) $
 
-our $VERSION = '0.6.1';
+our $VERSION = '0.6.2';
 
 use File::Path ();
 use File::Spec ();
@@ -159,7 +159,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::Tool::DevPack version 0.6.1
+    This documentation refers to LCFG::Build::Tool::DevPack version 0.6.2
 
 =head1 SYNOPSIS
 
