@@ -1,14 +1,14 @@
-package LCFG::Build::Tool::RPM;    # -*-cperl-*-
+package LCFG::Build::Tool::RPM;    # -*-perl-*-
 use strict;
 use warnings;
 
-# $Id: RPM.pm.in 15905 2011-02-17 17:01:27Z squinney@INF.ED.AC.UK $
+# $Id: RPM.pm.in 29224 2015-11-12 10:11:34Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Tool/RPM.pm.in,v $
-# $Revision: 15905 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_1/lib/LCFG/Build/Tool/RPM.pm.in $
-# $Date: 2011-02-17 17:01:27 +0000 (Thu, 17 Feb 2011) $
+# $Revision: 29224 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_2/lib/LCFG/Build/Tool/RPM.pm.in $
+# $Date: 2015-11-12 10:11:34 +0000 (Thu, 12 Nov 2015) $
 
-our $VERSION = '0.6.1';
+our $VERSION = '0.6.2';
 
 use LCFG::Build::Utils::RPM;
 use File::Basename ();
@@ -106,7 +106,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::Tool::RPM version 0.6.1
+    This documentation refers to LCFG::Build::Tool::RPM version 0.6.2
 
 =head1 SYNOPSIS
 
