@@ -1,14 +1,14 @@
-package LCFG::Build::Tool::SRPM;    # -*-cperl-*-
+package LCFG::Build::Tool::SRPM;    # -*-perl-*-
 use strict;
 use warnings;
 
-# $Id: SRPM.pm.in 12894 2010-07-12 15:44:11Z squinney@INF.ED.AC.UK $
+# $Id: SRPM.pm.in 29224 2015-11-12 10:11:34Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Tool/SRPM.pm.in,v $
-# $Revision: 12894 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_1/lib/LCFG/Build/Tool/SRPM.pm.in $
-# $Date: 2010-07-12 16:44:11 +0100 (Mon, 12 Jul 2010) $
+# $Revision: 29224 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_2/lib/LCFG/Build/Tool/SRPM.pm.in $
+# $Date: 2015-11-12 10:11:34 +0000 (Thu, 12 Nov 2015) $
 
-our $VERSION = '0.6.1';
+our $VERSION = '0.6.2';
 
 use Moose;
 
@@ -40,7 +40,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::Tool::SRPM version 0.6.1
+    This documentation refers to LCFG::Build::Tool::SRPM version 0.6.2
 
 =head1 SYNOPSIS
 
