@@ -1,14 +1,14 @@
-package LCFG::Build::Utils;    # -*-cperl-*-
+package LCFG::Build::Utils;    # -*-perl-*-
 use strict;
 use warnings;
 
-# $Id: Utils.pm.in 29146 2015-11-06 15:07:48Z squinney@INF.ED.AC.UK $
+# $Id: Utils.pm.in 29224 2015-11-12 10:11:34Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Utils.pm.in,v $
-# $Revision: 29146 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_1/lib/LCFG/Build/Utils.pm.in $
-# $Date: 2015-11-06 15:07:48 +0000 (Fri, 06 Nov 2015) $
+# $Revision: 29224 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_2/lib/LCFG/Build/Utils.pm.in $
+# $Date: 2015-11-12 10:11:34 +0000 (Thu, 12 Nov 2015) $
 
-our $VERSION = '0.6.1';
+our $VERSION = '0.6.2';
 
 use v5.10;
 
@@ -373,7 +373,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::Utils version 0.6.1
+    This documentation refers to LCFG::Build::Utils version 0.6.2
 
 =head1 SYNOPSIS
 
