@@ -1,14 +1,14 @@
-package LCFG::Build::Utils::OSXPkg;    # -*-cperl-*-
+package LCFG::Build::Utils::OSXPkg;    # -*-perl-*-
 use strict;
 use warnings;
 
-# $Id: OSXPkg.pm.in 29149 2015-11-06 15:21:39Z squinney@INF.ED.AC.UK $
+# $Id: OSXPkg.pm.in 29224 2015-11-12 10:11:34Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Utils/MacOSX.pm.in,v $
-# $Revision: 29149 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_1/lib/LCFG/Build/Utils/OSXPkg.pm.in $
-# $Date: 2015-11-06 15:21:39 +0000 (Fri, 06 Nov 2015) $
+# $Revision: 29224 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_2/lib/LCFG/Build/Utils/OSXPkg.pm.in $
+# $Date: 2015-11-12 10:11:34 +0000 (Thu, 12 Nov 2015) $
 
-our $VERSION = '0.6.1';
+our $VERSION = '0.6.2';
 
 use File::Copy ();
 use File::Spec ();
@@ -116,7 +116,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::Utils::OSXPkg version 0.6.1
+    This documentation refers to LCFG::Build::Utils::OSXPkg version 0.6.2
 
 =head1 DESCRIPTION
 
