@@ -1,14 +1,14 @@
-package LCFG::Build::Utils::RPM;    # -*-cperl-*-
+package LCFG::Build::Utils::RPM;    # -*-perl-*-
 use strict;
 use warnings;
 
-# $Id: RPM.pm.in 16250 2011-03-03 20:30:10Z squinney@INF.ED.AC.UK $
+# $Id: RPM.pm.in 29224 2015-11-12 10:11:34Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Utils/RPM.pm.in,v $
-# $Revision: 16250 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_1/lib/LCFG/Build/Utils/RPM.pm.in $
-# $Date: 2011-03-03 20:30:10 +0000 (Thu, 03 Mar 2011) $
+# $Revision: 29224 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_2/lib/LCFG/Build/Utils/RPM.pm.in $
+# $Date: 2015-11-12 10:11:34 +0000 (Thu, 12 Nov 2015) $
 
-our $VERSION = '0.6.1';
+our $VERSION = '0.6.2';
 
 use DateTime   ();
 use English qw(-no_match_vars);
@@ -275,7 +275,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::Utils::RPM version 0.6.1
+    This documentation refers to LCFG::Build::Utils::RPM version 0.6.2
 
 =head1 SYNOPSIS
 
